@@ -1,4 +1,4 @@
-from typing import List, Iterator, TYPE_CHECKING
+from typing import Dict, List, Iterator, TYPE_CHECKING
 
 from pyot.conf.model import models
 from pyot.core.functional import parse_camelcase
@@ -17,6 +17,7 @@ class LeaderboardPlayerData(PyotStatic):
     leaderboard_rank: int
     ranked_rating: int
     number_of_wins: int
+    competitive_tier: int
 
     @property
     def account(self) -> "Account":
@@ -24,16 +25,29 @@ class LeaderboardPlayerData(PyotStatic):
         return Account(puuid=self.puuid).pipeline(self.metapipeline.name)
 
 
+class LeaderboardTierDetailData(PyotStatic):
+    ranked_rating_threshold: int
+    starting_page: int
+    starting_index: int
+
+
 # PYOT CORE OBJECTS
 
 class Leaderboard(PyotCore):
     act_id: str
     total_players: int
     players: List[LeaderboardPlayerData]
+    immortal_starting_page: int
+    immortal_starting_index: int
+    top_tier_rr_threshold: int
+    tier_details: Dict[str, LeaderboardTierDetailData]
+    start_index: int
+    query_str: str
     shard: str
 
     class Meta(PyotCore.Meta):
         rules = {"ranked_v1_leaderboards": ["act_id"]}
+        renamed = {"query": "query_str"}
 
     def __init__(self, act_id: str = None, platform: str = models.val.DEFAULT_PLATFORM):
         self.initialize(locals())
